/*
 *
 * $Id: config.h,v 1.2.4.26 2000/02/21 06:35:11 ajp Exp $
 *
 * Andrew Pitman
 *
 * pvmsync, a distributed synchronization server:  configs.
 *
 * Copyright (C) 1999, 2000 Andrew J. Pitman
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/* config.h should probably be generated automatically by
   the configure script. */


#ifndef __CONFIG_H
#define __CONFIG_H


/* int64_t */
#include <sys/types.h>


/* Protocol version */
#define VERSION                  (char) 0x1


#if ((!defined __PVM_SD_H) && (!defined __HAVE_PVM_FLOAT64_T))
  /* 64 bit floating point */
  typedef double pvm_float64_t;
  #define __HAVE_PVM_FLOAT64_T
#endif /* !defined __HAVE_PVM_FLOAT64_T */

#if ((!defined __PVM_SD_H) && (!defined __HAVE_PVM_INT64_T))
  /* 64 bit integer */
  typedef int64_t pvm_int64_t;
  #define __HAVE_PVM_INT64_T
#endif /* !defined __HAVE_PVM_INT64_T */

/* Default timeout is a half-hour */
#define STALE_OBJECT_TIMEOUT     1800

/* Listen queue length */
#define SERVER_BACK_LOG          16

/* Ports for respective daemons...  these are the ports
   they listen on */
#define TCP_SERVER_PORT          1180
#define UDP_SERVER_PORT          1180

/* The maximum number of requests we can
   service `simultaneously'               */
#define CONCURRENT_CONNECTIONS   256

/* Max number of instances of basic types (soon to be deprecated) */
#define CONCURRENT_INSTANCES     256

/* Max objs */
#define MAX_OBJS                 8192

/* Number of entries in hash table */
/* Indexed/translated according to a-z, _, and A-Z */
#define NUM_HASH_ENTS            53

/* Concurrency level for pthreads */
#define PTHREAD_CONCURRENCY      8

/* Max length of pvmsync symbols */
#define SYMBOL_LENGTH            256

#ifndef PVM_MAX_SYMLEN
#define PVM_MAX_SYMLEN           255
#endif

/* Buffer length for each read   */
#define BUF_LENGTH               64

/* Max number of an FD to consider in select(2) */
#define MAX_FDS                  256

/* Max length of debug/run (log) filename path */
#define MAX_FILEPATH             256

/* Max host name length */
#define MAXHOSTNAMELEN           64

/* Name of PID files */
#define tcp_pid_file             "pvmsyncd.pid"
#define udp_pid_file             "pvmobjd.pid"

/* Run file names */
#ifdef __FILE_NEEDS_TCP_RUNFILE
static char tcp_run_file[] = "pvmsync.run";
#endif
#ifdef __FILE_NEEDS_UDP_RUNFILE
static char udp_run_file[] = "pvmobjd.run";
#endif


/* ----------------------------------------- */
/* There shouldn't be any reason to mess     */
/* with the lines below:                     */
/*                         --ajp             */
/* ----------------------------------------- */


/* Do not remove this block.  Protyping depends on it! */

#ifndef __P
# if (defined __STDC__ && __STDC__) || defined __cplusplus
#  if defined __GNUC__ && defined __cplusplus && __GNUC_MINOR__ >= 8
#   define __P(args)    args throw ()
#  else
#   define __P(args)    args
#  endif
#  define __PMT(args)   args
# else
#  define __P(args)     ()
#  define __PMT(args)   ()
# endif
#endif


#define HOSTNAMELEN              64

/* Boolean tests */
#define VALID                    1
#define INVALID                  0

/* Enable/Disable */
#define ENABLE                   1
#define DISABLE                  0

/* Mutex operation */
#define UNLOCKED                 INVALID


#endif /* __CONFIG_H */


